@@ -1,17 +1,14 @@
 from contextlib import contextmanager
 from queue import Queue
-from threading import Event, Timer, Thread
+from threading import Event, Timer
 from time import sleep
-from unittest import TestCase, skipIf
-import os
-import signal
-import sys
+from unittest import TestCase
+from unittest.mock import MagicMock
 
 from dakara_base.safe_workers import (
     BaseSafeThread,
     BaseWorker,
     Runner,
-    safe,
     SafeThread,
     SafeTimer,
     UnredefinedThreadError,
@@ -19,18 +16,18 @@ from dakara_base.safe_workers import (
     Worker,
     WorkerSafeThread,
     WorkerSafeTimer,
+    safe,
 )
 
 
-class TestError(Exception):
-    """Dummy error class
-    """
+class MyError(Exception):
+    """Dummy error class."""
 
     pass
 
 
 class BaseTestCase(TestCase):
-    """Generic test case
+    """Generic test case.
 
     It includes some dummy functions a new assertion method.
     """
@@ -41,21 +38,19 @@ class BaseTestCase(TestCase):
         self.errors = Queue()
 
     def function_safe(self):
-        """Function that does not raise any error
-        """
+        """Function that does not raise any error."""
         return
 
     def function_error(self):
-        """Function that raises a TestError
-        """
-        raise TestError("test error")
+        """Function that raises a MyError."""
+        raise MyError("test error")
 
     @contextmanager
     def assertNotRaises(self, ExceptionClass):
-        """Assert that the provided exception does not raise
+        """Assert that the provided exception does not raise.
 
         Args:
-            ExceptionClass (class): class of the exception.
+            ExceptionClass (class): Class of the exception.
         """
         try:
             yield None
@@ -65,12 +60,10 @@ class BaseTestCase(TestCase):
 
 
 class SafeTestCase(BaseTestCase):
-    """Test the `safe` decorator
-    """
+    """Test the `safe` decorator."""
 
     def create_classes(self):
-        """Create dummy classes
-        """
+        """Create dummy classes."""
 
         class Base:
             @safe
@@ -93,7 +86,7 @@ class SafeTestCase(BaseTestCase):
         return Thread, Worker, Other
 
     def test_worker_function_safe(self):
-        """Test a safe function of a worker
+        """Test a safe function of a worker.
 
         Test that a non-error function does not trigger any error, does not set
         the stop event and does not put an error in the error queue.
@@ -114,10 +107,10 @@ class SafeTestCase(BaseTestCase):
         self.assertTrue(self.errors.empty())
 
     def test_worker_function_error(self):
-        """Test an error function of a worker
+        """Test an error function of a worker.
 
         Test that an error function does not trigger any error, sets the stop
-        event and puts a TestError in the error queue.
+        event and puts a MyError in the error queue.
         """
         # pre assertions
         self.assertFalse(self.stop.is_set())
@@ -128,17 +121,17 @@ class SafeTestCase(BaseTestCase):
         worker = Worker(self.stop, self.errors)
 
         # call the method
-        with self.assertNotRaises(TestError):
+        with self.assertNotRaises(MyError):
             worker.function_error()
 
         # post assertions
         self.assertTrue(self.stop.is_set())
         self.assertFalse(self.errors.empty())
         _, error, _ = self.errors.get()
-        self.assertIsInstance(error, TestError)
+        self.assertIsInstance(error, MyError)
 
     def test_thread(self):
-        """Test a thread
+        """Test a thread.
 
         Test that a non-error function does not trigger any error, does not set
         the stop event and does not put an error in the error queue.
@@ -159,7 +152,7 @@ class SafeTestCase(BaseTestCase):
         self.assertTrue(self.errors.empty())
 
     def test_other(self):
-        """Test an other class
+        """Test an other class.
 
         Test that the decorator raises an error, as the class is not supported.
         """
@@ -181,16 +174,14 @@ class SafeTestCase(BaseTestCase):
 
 
 class SafeThreadTestCase(BaseTestCase):
-    """Test the SafeThread class
-    """
+    """Test the SafeThread class."""
 
     def create_controlled_thread(self, target):
-        """Helper to create a safe thread for a target function
-        """
+        """Helper to create a safe thread for a target function."""
         return SafeThread(self.stop, self.errors, target=target)
 
     def test_function_safe(self):
-        """Test a safe function
+        """Test a safe function.
 
         Test that a non-error function run as a thread does not trigger any
         error, does not set the stop event and does not put an error in the
@@ -212,10 +203,10 @@ class SafeThreadTestCase(BaseTestCase):
         self.assertTrue(self.errors.empty())
 
     def test_function_error(self):
-        """Test an error function
+        """Test an error function.
 
         Test that an error function run as a thread does not trigger any error,
-        sets the stop event and puts a TestError in the error queue.
+        sets the stop event and puts a MyError in the error queue.
         """
         # pre assertions
         self.assertFalse(self.stop.is_set())
@@ -225,7 +216,7 @@ class SafeThreadTestCase(BaseTestCase):
         controlled_thread = self.create_controlled_thread(self.function_error)
 
         # run thread
-        with self.assertNotRaises(TestError):
+        with self.assertNotRaises(MyError):
             controlled_thread.start()
             controlled_thread.join()
 
@@ -233,15 +224,14 @@ class SafeThreadTestCase(BaseTestCase):
         self.assertTrue(self.stop.is_set())
         self.assertFalse(self.errors.empty())
         _, error, _ = self.errors.get()
-        self.assertIsInstance(error, TestError)
+        self.assertIsInstance(error, MyError)
 
 
 class SafeTimerTestCase(SafeThreadTestCase):
-    """Test the SafeTimer class
-    """
+    """Test the SafeTimer class."""
 
     def create_controlled_thread(self, target):
-        """Helper to create a safe timer thread for a target function
+        """Helper to create a safe timer thread for a target function.
 
         The delay is non null (0.5 s).
         """
@@ -249,11 +239,10 @@ class SafeTimerTestCase(SafeThreadTestCase):
 
 
 class WorkerTestCase(BaseTestCase):
-    """Test the Worker class
-    """
+    """Test the Worker class."""
 
     def test_run_safe(self):
-        """Test a safe run
+        """Test a safe run.
 
         Test that a worker used with no error does not produce any error,
         finishes with a triggered stop event and an empty error queue.
@@ -271,7 +260,7 @@ class WorkerTestCase(BaseTestCase):
         self.assertTrue(self.errors.empty())
 
     def test_run_error(self):
-        """Test a run with error
+        """Test a run with error.
 
         Test that a worker used with error does produce an error, finishes
         with a triggered stop event and an empty error queue.
@@ -281,7 +270,7 @@ class WorkerTestCase(BaseTestCase):
         self.assertTrue(self.errors.empty())
 
         # create and run worker
-        with self.assertRaises(TestError):
+        with self.assertRaises(MyError):
             with Worker(self.stop, self.errors):
                 self.function_error()
 
@@ -292,7 +281,7 @@ class WorkerTestCase(BaseTestCase):
         self.assertTrue(self.errors.empty())
 
     def test_run_thread_safe(self):
-        """Test a run with a safe thread
+        """Test a run with a safe thread.
 
         Test that a worker used with a non-error thread does not produce any
         error, finishes with a triggered stop event and an empty error queue.
@@ -312,7 +301,7 @@ class WorkerTestCase(BaseTestCase):
         self.assertTrue(self.errors.empty())
 
     def test_run_thread_error(self):
-        """Test a run with a thread with error
+        """Test a run with a thread with error.
 
         Test that a worker used with a thread with an error does not produce
         any error, finishes with a triggered stop event and a non-empty error
@@ -323,7 +312,7 @@ class WorkerTestCase(BaseTestCase):
         self.assertTrue(self.errors.empty())
 
         # create and run worker
-        with self.assertNotRaises(TestError):
+        with self.assertNotRaises(MyError):
             with Worker(self.stop, self.errors) as worker:
                 worker.thread = worker.create_thread(target=self.function_error)
                 worker.thread.start()
@@ -333,35 +322,30 @@ class WorkerTestCase(BaseTestCase):
         self.assertTrue(self.stop.is_set())
         self.assertFalse(self.errors.empty())
         _, error, _ = self.errors.get()
-        self.assertIsInstance(error, TestError)
+        self.assertIsInstance(error, MyError)
 
 
 class WorkerSafeTimerTestCase(BaseTestCase):
-    """Test the WorkerSafeTimer class
-    """
+    """Test the WorkerSafeTimer class."""
 
     class WorkerSafeTimerToTest(WorkerSafeTimer):
-        """Dummy worker class
-        """
+        """Dummy worker class."""
 
         def function_already_dead(self):
-            """Function that ends immediately
-            """
+            """Function that ends immediately."""
             return
 
         def function_to_cancel(self):
-            """Function that calls itself in loop every second
-            """
+            """Function that calls itself in loop every second."""
             self.timer = Timer(1, self.function_to_cancel)
             self.timer.start()
 
         def function_to_join(self):
-            """Function that waits one second
-            """
+            """Function that waits one second."""
             sleep(1)
 
     def test_run_timer_dead(self):
-        """Test to end a worker when its timer is dead
+        """Test to end a worker when its timer is dead.
 
         Test that a worker worker stopped with a dead timer finishes with a
         triggered stop event, an empty error queue and a still dead timer.
@@ -382,7 +366,7 @@ class WorkerSafeTimerTestCase(BaseTestCase):
         self.assertFalse(worker.timer.is_alive())
 
     def test_run_timer_cancelled(self):
-        """Test to end a deamon when its timer is waiting
+        """Test to end a deamon when its timer is waiting.
 
         Test that a worker worker stopped with a waiting timer finishes with a
         triggered stop event, an empty error queue and a dead timer.
@@ -404,7 +388,7 @@ class WorkerSafeTimerTestCase(BaseTestCase):
         self.assertTrue(worker.timer.finished.is_set())
 
     def test_run_timer_joined(self):
-        """Test to end a deamon when its timer is running
+        """Test to end a deamon when its timer is running.
 
         Test that a worker worker stopped with a running timer finishes with a
         triggered stop event, an empty error queue and a dead timer.
@@ -425,7 +409,7 @@ class WorkerSafeTimerTestCase(BaseTestCase):
         self.assertFalse(worker.timer.is_alive())
 
     def test_unredifined_timer(self):
-        """Test the timer must be redefined
+        """Test the timer must be redefined.
 
         Test that a worker worker with its default timer does not generate an
         error, but finishes with a triggered stop event and an non-empty error
@@ -448,25 +432,21 @@ class WorkerSafeTimerTestCase(BaseTestCase):
 
 
 class WorkerSafeThreadTestCase(BaseTestCase):
-    """Test the WorkerSafeThread class
-    """
+    """Test the WorkerSafeThread class."""
 
     class WorkerSafeThreadToTest(WorkerSafeThread):
-        """Dummy worker class
-        """
+        """Dummy worker class."""
 
         def function_already_dead(self):
-            """Function that ends immediately
-            """
+            """Function that ends immediately."""
             return
 
         def function_to_join(self):
-            """Function that waits one second
-            """
+            """Function that waits one second."""
             sleep(1)
 
     def test_run_thread_dead(self):
-        """Test to end a worker when its thread is dead
+        """Test to end a worker when its thread is dead.
 
         Test that a worker worker stopped with a dead thread finishes with a
         triggered stop event, an empty error queue and a still dead thread.
@@ -487,7 +467,7 @@ class WorkerSafeThreadTestCase(BaseTestCase):
         self.assertFalse(worker.thread.is_alive())
 
     def test_run_thread_joined(self):
-        """Test to end a deamon when its thread is running
+        """Test to end a deamon when its thread is running.
 
         Test that a worker worker stopped with a running thread finishes with a
         triggered stop event, an empty error queue and a dead thread.
@@ -508,7 +488,7 @@ class WorkerSafeThreadTestCase(BaseTestCase):
         self.assertFalse(worker.thread.is_alive())
 
     def test_unredifined_thread(self):
-        """Test the thread must be redefined
+        """Test the thread must be redefined.
 
         Test that a worker worker with its default thread does not generate an
         error, but finishes with a triggered stop event and an non-empty error
@@ -531,58 +511,36 @@ class WorkerSafeThreadTestCase(BaseTestCase):
 
 
 class RunnerTestCase(BaseTestCase):
-    """Test the Runner class
+    """Test the Runner class.
 
     The class to test should leave because of a Ctrl+C, or because of an
     internal eror.
     """
 
-    class WorkerError(Worker):
-        """Dummy worker class
-        """
+    class WorkerNormal(Worker):
+        """Dummy worker class."""
 
         def init_worker(self):
-            """Initialize the worker
-            """
             self.thread = self.create_thread(target=self.test)
 
         def test(self):
-            """Raise an error
-            """
-            raise TestError("test error")
+            pass
 
-    @staticmethod
-    def get_worker_ready():
-        """Get a worker connected to an event
+    class WorkerError(Worker):
+        """Dummy worker class that will fail."""
 
-        This will be used for tests that produce side effects.
-        """
-        ready = Event()
+        def init_worker(self):
+            self.thread = self.create_thread(target=self.test)
 
-        class WorkerReady(Worker):
-            """Dummy worker class
-            """
-
-            def init_worker(self):
-                """Initialize the worker
-                """
-                self.thread = self.create_thread(target=self.test)
-
-            def test(self):
-                """Signal to stop
-                """
-                ready.set()
-                return
-
-        return ready, WorkerReady
+        def test(self):
+            raise MyError("test error")
 
     def setUp(self):
         # create class to test
         self.runner = Runner()
 
-    @skipIf(os.environ.get("APPVEYOR_CI_ENV", False), "Disabled for Appveyor CI")
-    def test_run_interrupt(self):
-        """Test a run with an interruption by Ctrl+C
+    def test_run_safe_interrupt(self):
+        """Test a run with an interruption by KeyboardInterrupt exception.
 
         The run should end with a set stop event and an empty errors queue.
         """
@@ -590,39 +548,24 @@ class RunnerTestCase(BaseTestCase):
         self.assertFalse(self.runner.stop.is_set())
         self.assertTrue(self.runner.errors.empty())
 
-        # get the class
-        ready, WorkerReady = self.get_worker_ready()
-
-        # prepare the sending of SIGINT to simulate a Ctrl+C
-        def send_ctrl_c():
-            """Simulate the Ctrl+C
-
-            The signal is SIGINT on *NIX and  CTRL_C_EVENT on Windows.
-            """
-            pid = os.getpid()
-            ready.wait()
-            if sys.platform.startswith("win"):
-                os.kill(pid, signal.CTRL_C_EVENT)
-
-            else:
-                os.kill(pid, signal.SIGINT)
-
-        kill_thread = Thread(target=send_ctrl_c)
-        kill_thread.start()
+        # modify stop event wait method
+        self.runner.stop.wait = MagicMock()
+        self.runner.stop.wait.side_effect = KeyboardInterrupt
 
         # call the method
-        with self.assertNotRaises(KeyboardInterrupt):
-            self.runner.run_safe(WorkerReady)
+        self.runner.run_safe(self.WorkerNormal)
 
         # post assertions
         self.assertTrue(self.runner.stop.is_set())
         self.assertTrue(self.runner.errors.empty())
-        self.assertFalse(kill_thread.is_alive())
 
-    def test_run_error(self):
-        """Test a run with an error
+        # assert stop event wait method was called
+        self.runner.stop.wait.assert_called_once()
 
-        The run should raise a TestError, end with a set stop event and an
+    def test_run_safe_error(self):
+        """Test a run with an error.
+
+        The run should raise a MyError, end with a set stop event and an
         empty error queue.
         """
         # pre assertions
@@ -630,7 +573,7 @@ class RunnerTestCase(BaseTestCase):
         self.assertTrue(self.runner.errors.empty())
 
         # call the method
-        with self.assertRaises(TestError):
+        with self.assertRaises(MyError):
             self.runner.run_safe(self.WorkerError)
 
         # post assertions
